# Tapl Lang

<!--
Part of the Tapl Language project, under the Apache License v2.0 with LLVM
Exceptions. See /LICENSE for license information.
SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-->

[![PyPI - Version](https://img.shields.io/pypi/v/tapl-lang.svg)](https://pypi.org/project/tapl-lang)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tapl-lang.svg)](https://pypi.org/project/tapl-lang)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install tapl-lang
```

## License

`tapl-lang` is distributed under the terms of the [Apache-2.0 WITH LLVM-exception](https://spdx.org/licenses/Apache-2.0.html) license.
